@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2015-2018 Canonical, Ltd.
+# Copyright (c) 2015-2021 Canonical, Ltd.
 #
 # This file is part of Talisker
 # (see http://github.com/canonical-ols/talisker).
@@ -22,15 +22,6 @@
 # under the License.
 #
 
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
-
-from builtins import *  # noqa
-__metaclass__ = type
-
-
 from collections import OrderedDict
 from datetime import datetime
 import logging
@@ -391,6 +382,7 @@ class TaliskerWSGIRequest():
         # c) manual debugging
 
         if talisker.sentry.enabled:
+            view_or_path = metadata.get('view', metadata['path'])
             soft_timeout = Context.soft_timeout
             try:
                 if self.exc_info:
@@ -398,13 +390,13 @@ class TaliskerWSGIRequest():
                 elif Context.debug:
                     self.send_sentry(
                         metadata,
-                        msg='Debug: {}'.format(metadata['path']),
+                        msg='Debug: {}'.format(view_or_path),
                         level='debug',
                     )
                 elif soft_timeout > 0 and response_latency > soft_timeout:
                     self.send_sentry(
                         metadata,
-                        msg='Soft Timeout: {}'.format(metadata['path']),
+                        msg='Soft Timeout: {}'.format(view_or_path),
                         level='warning',
                         extra={
                             'start_response_latency': response_latency,
@@ -518,6 +510,9 @@ class TaliskerWSGIRequest():
             data = {}
         if 'SENTRY_ID' in self.environ:
             data['event_id'] = self.environ['SENTRY_ID']
+        view_name = metadata.get('view')
+        if view_name and 'transaction' not in data:
+            data['transaction'] = view_name
         # sentry displays these specific fields in a different way
         http_context = {
             'url': get_current_url(self.environ),
